Changelog
=========

1.0.0 (2021-01-04)
------------------

- MWEBIMI-25: Hide slides after the first one to improve page loading
  [mpeeters]


1.0a7 (2020-02-10)
------------------

- Add attributes for slick.
  Serveral options to make custom responsive slider.
  [thomlamb]


1.0a6 (2020-02-06)
------------------

- Bad release
  [bsuttor]


1.0a5 (2020-01-06)
------------------

- Updating attr for slick.
  add centerMode, fade, vertical, autoplay, pauseOnFocus, cssEase, autoplaySpeed attr.
  [thomlamb]


1.0a4 (2020-01-29)
------------------

- integration of imio.patterns made by Aurore
  (affinitic & boulch) during the january 2020 sprint.
  The actual imio.patterns (https://github.com/IMIO/imio.patterns)
  just adds a slider (using https://kenwheeler.github.io/slick/)
  and was made to test functionnalities before the integration.
  It's been merged and so is this release.
  [AuroreMariscal, boulch, thomlamb, dmshd]


1.0a3 (2019-08-02)
------------------

- Add resources for slider.
  [bsuttor]

- Adapt news and events tile for folder
  [AuroreMariscal]


1.0a2 (2019-04-02)
------------------

- Display dates if the element is an event
  [mpeeters]


1.0a1 (2019-02-23)
------------------

- Adapt template of news
  [AuroreMariscal]

- Initial release.
  [AuroreMariscal]
